@@ -8,7 +8,7 @@
 
 
 static int ngx_http_lua_parse_args(ngx_http_request_t *r, lua_State *L,
-        u_char *buf, u_char *last);
+    u_char *buf, u_char *last, int max);
 static int ngx_http_lua_ngx_req_set_uri_args(lua_State *L);
 static int ngx_http_lua_ngx_req_get_uri_args(lua_State *L);
 static int ngx_http_lua_ngx_req_get_post_args(lua_State *L);
@@ -80,10 +80,21 @@ ngx_http_lua_ngx_req_get_uri_args(lua_State *L) {
     u_char                      *buf;
     u_char                      *last;
     int                          retval;
+    int                          n;
+    int                          max;
 
-    if (lua_gettop(L) != 0) {
-        return luaL_error(L, "expecting 0 arguments but seen %d",
-                lua_gettop(L));
+    n = lua_gettop(L);
+
+    if (n != 0 && n != 1) {
+        return luaL_error(L, "expecting 0 or 1 arguments but seen %d", n);
+    }
+
+    if (n == 1) {
+        max = luaL_checkinteger(L, 1);
+        lua_pop(L, 1);
+
+    } else {
+        max = NGX_HTTP_LUA_MAX_ARGS;
     }
 
     lua_getglobal(L, GLOBALS_SYMBOL_REQUEST);
@@ -108,7 +119,7 @@ ngx_http_lua_ngx_req_get_uri_args(lua_State *L) {
 
     last = buf + r->args.len;
 
-    retval = ngx_http_lua_parse_args(r, L, buf, last);
+    retval = ngx_http_lua_parse_args(r, L, buf, last, max);
 
     ngx_pfree(r->pool, buf);
 
@@ -126,10 +137,21 @@ ngx_http_lua_ngx_req_get_post_args(lua_State *L)
     ngx_chain_t                 *cl;
     u_char                      *p;
     u_char                      *last;
+    int                          n;
+    int                          max;
 
-    if (lua_gettop(L) != 0) {
-        return luaL_error(L, "expecting 0 arguments but seen %d",
-                lua_gettop(L));
+    n = lua_gettop(L);
+
+    if (n != 0 && n != 1) {
+        return luaL_error(L, "expecting 0 or 1 arguments but seen %d", n);
+    }
+
+    if (n == 1) {
+        max = luaL_checkinteger(L, 1);
+        lua_pop(L, 1);
+
+    } else {
+        max = NGX_HTTP_LUA_MAX_ARGS;
     }
 
     lua_getglobal(L, GLOBALS_SYMBOL_REQUEST);
@@ -184,7 +206,7 @@ ngx_http_lua_ngx_req_get_post_args(lua_State *L)
 
     last = buf + len;
 
-    retval = ngx_http_lua_parse_args(r, L, buf, last);
+    retval = ngx_http_lua_parse_args(r, L, buf, last, max);
 
     ngx_pfree(r->pool, buf);
 
@@ -194,12 +216,13 @@ ngx_http_lua_ngx_req_get_post_args(lua_State *L)
 
 static int
 ngx_http_lua_parse_args(ngx_http_request_t *r, lua_State *L, u_char *buf,
-        u_char *last)
+        u_char *last, int max)
 {
     u_char                      *p, *q;
     u_char                      *src, *dst;
     unsigned                     parsing_value;
     size_t                       len;
+    int                          count = 0;
 
     p = buf;
 
@@ -267,6 +290,13 @@ ngx_http_lua_parse_args(ngx_http_request_t *r, lua_State *L, u_char *buf,
                 ngx_http_lua_set_multi_value_table(L, 1);
             }
 
+            if (max > 0 && ++count == max) {
+                ngx_log_debug1(NGX_LOG_DEBUG_HTTP, r->connection->log, 0,
+                        "lua hit query args limit %d", max);
+
+                return 1;
+            }
+
         } else {
             p++;
         }
@@ -302,6 +332,7 @@ ngx_http_lua_parse_args(ngx_http_request_t *r, lua_State *L, u_char *buf,
 
     dd("gettop: %d", lua_gettop(L));
     dd("type: %s", lua_typename(L, lua_type(L, 1)));
+
     if (lua_gettop(L) != 1) {
         return luaL_error(L, "internal error: stack in bad state");
     }
