@@ -1,6 +1,8 @@
 /* vim:set ft=c ts=4 sw=4 et fdm=marker: */
 
+#ifndef DDEBUG
 #define DDEBUG 0
+#endif
 
 #include <nginx.h>
 #include "ngx_http_lua_capturefilter.h"
