@@ -65,7 +65,9 @@ ngx_http_lua_header_filter_by_lua_env(lua_State *L, ngx_http_request_t *r)
 #endif /* defined(NDK) && NDK */
 
     /*  {{{ initialize ngx.* namespace */
-    lua_newtable(L);    /*  ngx.* */
+    lua_createtable(L, 0 /* narr */, 67 /* nrec */);    /*  ngx.* */
+
+    ngx_http_lua_inject_internal_utils(r->connection->log, L);
 
     ngx_http_lua_inject_http_consts(L);
     ngx_http_lua_inject_core_consts(L);
@@ -76,7 +78,7 @@ ngx_http_lua_header_filter_by_lua_env(lua_State *L, ngx_http_request_t *r)
 #if (NGX_PCRE)
     ngx_http_lua_inject_regex_api(L);
 #endif
-    ngx_http_lua_inject_req_api_no_io(L);
+    ngx_http_lua_inject_req_api_no_io(r->connection->log, L);
     ngx_http_lua_inject_resp_header_api(L);
     ngx_http_lua_inject_variable_api(L);
     ngx_http_lua_inject_shdict_api(lmcf, L);
